package common

import (
	"bytes"
	"context"
	"encoding/csv"
	"encoding/json"
	"net/http"
)

func HTTPGet(ctx context.Context, url string) (*bytes.Buffer, error) {
	buf := new(bytes.Buffer)

	req, err := http.NewRequestWithContext(ctx, "GET", url, nil)
	if err != nil {
		return buf, err
	}

	resp, err := http.DefaultClient.Do(req)
	if err != nil {
		return buf, err
	}
	defer resp.Body.Close()

	if _, err := buf.ReadFrom(resp.Body); err != nil {
		return nil, err
	}

	return buf, nil
}

func HTTPGetJson(ctx context.Context, url string, into interface{}) error {
	body, err := HTTPGet(ctx, url)
	if err != nil {
		return err
	}
	return json.NewDecoder(body).Decode(into)
}

func HTTPGetCsv(ctx context.Context, url string, sep rune) ([][]string, error) {
	body, err := HTTPGet(ctx, url)
	if err != nil {
		return nil, err
	}
	r := csv.NewReader(body)
	r.Comma = sep
	return r.ReadAll()
}
