# `zookeeper` module
## Metrics
| Metric name | Labels | Description | 
| ----------- | ------ | ---- |
| openio_zookeeper_alive_connections           | `service_addr`, `service`, `service_type`              | Number of active clients connected |
| openio_zookeeper_approximate_data_size_bytes | `service_addr`, `service`, `service_type`              | Size of data in bytes |
| openio_zookeeper_followers                   | `service_addr`, `service`, `service_type`              | Number of followers when the zookeeper is leader |
| openio_zookeeper_items                       | `service_addr`, `service`, `service_type`, `type`      | Number of items by type (`znode`, `watch`, `ephemerals`) |
| openio_zookeeper_latency_seconds_avg         | `service_addr`, `service`, `service_type`              | Average time for requests to be processed |
| openio_zookeeper_latency_seconds_min         | `service_addr`, `service`, `service_type`              | Min time for requests to be processed |
| openio_zookeeper_latency_seconds_max         | `service_addr`, `service`, `service_type`              | Max time for requests to be processed |
| openio_zookeeper_open_files                  | `service_addr`, `service`, `service_type`              | Number of current open files |
| openio_zookeeper_open_files_max              | `service_addr`, `service`, `service_type`              | Max number of open files |
| openio_zookeeper_outstanding_requests        | `service_addr`, `service`, `service_type`              | Number of currently executing requests |
| openio_zookeeper_packets                     | `service_addr`, `service`, `service_type`, `direction` | Cumulative number of ZooKeeper packets by direction (`in` or `out`) |
| openio_zookeeper_pending_syncs               | `service_addr`, `service`, `service_type`              | Number of pending syncs |
| openio_zookeeper_proposal_size               | `service_addr`, `service`, `service_type`              | from `zk_last_proposal_size` when the zookeeper is leader |
| openio_zookeeper_proposal_size_min           | `service_addr`, `service`, `service_type`              | from `zk_min_proposal_size` when the zookeeper is leader |
| openio_zookeeper_proposal_size_max           | `service_addr`, `service`, `service_type`              | from `zk_max_proposal_size` when the zookeeper is leader |
| openio_zookeeper_server_state                | `service_addr`, `service`, `service_type`, `role`      | Zookeeper state by role (`leader` or `follower`) |
| openio_zookeeper_synced_followers            | `service_addr`, `service`, `service_type`              | Number of synchronized followers when the zookeeper is leader |
### Sample
```
openio_zookeeper_alive_connections{host="gw",namespace="OPENIO",service_type="zookeeper",service_addr="172.30.0.112:6005"} 6.000000
openio_zookeeper_approximate_data_size_bytes{host="gw",namespace="OPENIO",service_type="zookeeper",service_addr="172.30.0.112:6005"} 1960686.000000
openio_zookeeper_followers{host="gw",namespace="OPENIO",service_type="zookeeper",service_addr="172.30.0.112:6005"} 2.000000
openio_zookeeper_items{host="gw",namespace="OPENIO",service_type="zookeeper",service_addr="172.30.0.112:6005",type="ephemerals"} 102.000000
openio_zookeeper_items{host="gw",namespace="OPENIO",service_type="zookeeper",service_addr="172.30.0.112:6005",type="watch"} 50.000000
openio_zookeeper_items{host="gw",namespace="OPENIO",service_type="zookeeper",service_addr="172.30.0.112:6005",type="znode"} 70007.000000
openio_zookeeper_latency_seconds_avg{host="gw",namespace="OPENIO",service_type="zookeeper",service_addr="172.30.0.112:6005"} 0.002000
openio_zookeeper_latency_seconds_max{host="gw",namespace="OPENIO",service_type="zookeeper",service_addr="172.30.0.112:6005"} 0.127000
openio_zookeeper_latency_seconds_min{host="gw",namespace="OPENIO",service_type="zookeeper",service_addr="172.30.0.112:6005"} 0.000000
openio_zookeeper_open_files{host="gw",namespace="OPENIO",service_type="zookeeper",service_addr="172.30.0.112:6005"} 66.000000
openio_zookeeper_open_files_max{host="gw",namespace="OPENIO",service_type="zookeeper",service_addr="172.30.0.112:6005"} 65536.000000
openio_zookeeper_outstanding_requests{host="gw",namespace="OPENIO",service_type="zookeeper",service_addr="172.30.0.112:6005"} 0.000000
openio_zookeeper_packets{host="gw",namespace="OPENIO",service_type="zookeeper",service_addr="172.30.0.112:6005",direction="in"} 569447.000000
openio_zookeeper_packets{host="gw",namespace="OPENIO",service_type="zookeeper",service_addr="172.30.0.112:6005",direction="out"} 586822.000000
openio_zookeeper_pending_syncs{host="gw",namespace="OPENIO",service_type="zookeeper",service_addr="172.30.0.112:6005"} 0.000000
openio_zookeeper_proposal_size{host="gw",namespace="OPENIO",service_type="zookeeper",service_addr="172.30.0.112:6005"} 140.000000
openio_zookeeper_proposal_size_max{host="gw",namespace="OPENIO",service_type="zookeeper",service_addr="172.30.0.112:6005"} 193.000000
openio_zookeeper_proposal_size_min{host="gw",namespace="OPENIO",service_type="zookeeper",service_addr="172.30.0.112:6005"} 32.000000
openio_zookeeper_server_state{host="gw",namespace="OPENIO",service_type="zookeeper",service_addr="172.30.0.112:6005",role="leader"} 1587443533.000000
openio_zookeeper_synced_followers{host="gw",namespace="OPENIO",service_type="zookeeper",service_addr="172.30.0.112:6005"} 2.000000
```
